Title: [165329] trunk/Source/WebKit2
Revision
165329
Author
commit-qu...@webkit.org
Date
2014-03-08 00:33:03 -0800 (Sat, 08 Mar 2014)

Log Message

Prevent processes spawned by WebProcess from trying to insert the SecItem shim.
https://bugs.webkit.org/show_bug.cgi?id=129864

Patch by Aaron Golden <gol...@inkling.com> on 2014-03-08
Reviewed by Anders Carlsson.

* WebProcess/EntryPoint/mac/LegacyProcess/WebContentProcessMain.mm:
(WebKit::WebContentProcessMainDelegate::doPreInitializationWork):

Modified Paths

Diff

Modified: trunk/Source/WebKit2/ChangeLog (165328 => 165329)


--- trunk/Source/WebKit2/ChangeLog	2014-03-08 08:08:46 UTC (rev 165328)
+++ trunk/Source/WebKit2/ChangeLog	2014-03-08 08:33:03 UTC (rev 165329)
@@ -1,3 +1,13 @@
+2014-03-08  Aaron Golden  <gol...@inkling.com>
+
+        Prevent processes spawned by WebProcess from trying to insert the SecItem shim.
+        https://bugs.webkit.org/show_bug.cgi?id=129864
+
+        Reviewed by Anders Carlsson.
+
+        * WebProcess/EntryPoint/mac/LegacyProcess/WebContentProcessMain.mm:
+        (WebKit::WebContentProcessMainDelegate::doPreInitializationWork):
+
 2014-03-07  Tim Horton  <timothy_hor...@apple.com>
 
         [WebKit2][iOS] PDF

Modified: trunk/Source/WebKit2/WebProcess/EntryPoint/mac/LegacyProcess/WebContentProcessMain.mm (165328 => 165329)


--- trunk/Source/WebKit2/WebProcess/EntryPoint/mac/LegacyProcess/WebContentProcessMain.mm	2014-03-08 08:08:46 UTC (rev 165328)
+++ trunk/Source/WebKit2/WebProcess/EntryPoint/mac/LegacyProcess/WebContentProcessMain.mm	2014-03-08 08:33:03 UTC (rev 165329)
@@ -66,9 +66,10 @@
 
     virtual void doPreInitializationWork()
     {
         // Remove the WebProcess shim from the DYLD_INSERT_LIBRARIES environment variable so any processes spawned by
         // the WebProcess don't try to insert the shim and crash.
         EnvironmentUtilities::stripValuesEndingWithString("DYLD_INSERT_LIBRARIES", "/WebProcessShim.dylib");
+        EnvironmentUtilities::stripValuesEndingWithString("DYLD_INSERT_LIBRARIES", "/SecItemShim.dylib");
     
 #if USE(APPKIT)
         // Initialize AppKit.
@@ -66,9 +66,10 @@
     virtual void doPreInitializationWork()
     {
-        // Remove the WebProcess shim from the DYLD_INSERT_LIBRARIES environment variable so any processes spawned by
-        // the WebProcess don't try to insert the shim and crash.
+        // Remove the WebProcess and SecItem shims from the DYLD_INSERT_LIBRARIES environment variable so any processes
+        // spawned by the WebProcess don't try to insert the shims and crash.
         EnvironmentUtilities::stripValuesEndingWithString("DYLD_INSERT_LIBRARIES", "/WebProcessShim.dylib");
_______________________________________________
webkit-changes mailing list
webkit-changes@lists.webkit.org
https://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to